==> mobile_pos-1.1.1.tar.gz: lib/src/views/dispute/add_bank_sheet.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/shared_widgets/purchase_amount.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_textfeild.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_info_screen.dart';
import 'package:pinput/pinput.dart';

class AddCustomerBank extends StatelessWidget {
  final Function(String, String) onDone;
  final accountName = TextEditingController();
  final bankName = TextEditingController();
  AddCustomerBank({super.key, required this.onDone});

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding) +
          EdgeInsets.only(bottom: MediaQuery.of(context).viewInsets.bottom),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          const Gap(20),
          const RavenPayBottomSheetCapsule(),
          const Gap(24),
          Row(
            children: [
              Expanded(
                  child: Text("Add Customer Bank",
                      style: headling1.copyWith(fontSize: 20))),
              GestureDetector(
                onTap: () {
                  Navigator.pop(context);
                },
                child: RoundedItemContainer(
                    asset: "cancel_icon.png",
                    imageColor: pluginTheme.isLightTheme ? null : Colors.white),
              ),
            ],
          ),
          const Gap(24),
          RavenPayTextField(
            controller: bankName,
            labelText: "Bank Name",
            hintText: "Select bank",
          ),
          const Gap(20),
          RavenPayTextField(
            controller: accountName,
            labelText: "Account Number",
            hintText: "Enter account number",
          ),
          const Gap(34),
          RavenPayButton(
            buttonText: "Proceed",
            onPressed: () {
              if (bankName.length < 2) {
                showSnack(context, "invalid bank name");
                return;
              }
              if (accountName.length < 10) {
                showSnack(context, "invalid account number");
                return;
              }
              Navigator.pop(context);
              onDone(bankName.text, accountName.text);
            },
          ),
          const BottomNavSpacer()
        ],
      ),
    );
  }
}

==> mobile_pos-2.0.0.tar.gz: lib/src/views/dispute/add_bank_sheet.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/shared_widgets/purchase_amount.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet_capsule.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_textfeild.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_terminal_details.dart';
import 'package:pinput/pinput.dart';

class AddCustomerBank extends StatelessWidget {
  final Function(String, String) onDone;
  final accountName = TextEditingController();
  final bankName = TextEditingController();
  AddCustomerBank({super.key, required this.onDone});

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding) +
          EdgeInsets.only(bottom: MediaQuery.of(context).viewInsets.bottom),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          const Gap(20),
          const RavenPayBottomSheetCapsule(),
          const Gap(24),
          Row(
            children: [
              Expanded(
                  child: Text("Add Customer Bank",
                      style: headling1.copyWith(fontSize: 20))),
              GestureDetector(
                onTap: () {
                  Navigator.pop(context);
                },
                child: RoundedItemContainer(
                    asset: "cancel_icon.png",
                    imageColor: pluginTheme.isLightTheme ? null : Colors.white),
              ),
            ],
          ),
          const Gap(24),
          RavenPayTextField(
            controller: bankName,
            labelText: "Bank Name",
            hintText: "Select bank",
          ),
          const Gap(20),
          RavenPayTextField(
            controller: accountName,
            labelText: "Account Number",
            hintText: "Enter account number",
          ),
          const Gap(34),
          RavenPayButton(
            buttonText: "Proceed",
            onPressed: () {
              if (bankName.length < 2) {
                showSnack(context, "invalid bank name");
                return;
              }
              if (accountName.length < 10) {
                showSnack(context, "invalid account number");
                return;
              }
              Navigator.pop(context);
              onDone(bankName.text, accountName.text);
            },
          ),
          const BottomNavSpacer()
        ],
      ),
    );
  }
}
